@@ -1,15 +1,13 @@
 #!/usr/bin/env python
-
+# -*- coding: utf-8 -*-
 import psutil
-
 import plugins
 
 
 class Plugin(plugins.BasePlugin):
-
+    __name__ = 'cpu'
 
     def run(self, *unused):
-        name = 'cpu'
         results = {}
         data = psutil.cpu_times_percent(interval=1, percpu=True)
         cpu_number = -1
@@ -21,7 +19,7 @@ class Plugin(plugins.BasePlugin):
                 core[key] = getattr(cpu, key)
             results[cpu_number] = core
         return results
-    
-    
+
+
 if __name__ == '__main__':
     Plugin().execute()
