@@ -1,14 +1,11 @@
 #!/usr/bin/env python
-
-
+# -*- coding: utf-8 -*-
 import psutil
-
-
 import plugins
 
 
 class Plugin(plugins.BasePlugin):
-
+    __name__ = 'network'
 
     def run(self, *unused):
         return psutil.net_io_counters(pernic=True)
@@ -16,4 +13,3 @@ class Plugin(plugins.BasePlugin):
 
 if __name__ == '__main__':
     Plugin().execute()
-
