@@ -1,14 +1,12 @@
 #!/usr/bin/env python
-
-
+# -*- coding: utf-8 -*-
 import time
-
 import plugins
 
 
 class Plugin(plugins.BasePlugin):
+    __name__ = 'sleeper'
 
-    
     def run(self, *unused):
         time.sleep(60 * 60 * 24)
 
